@@ -80,14 +80,14 @@ def new_sshfs_connection(sshfs_parameters, keyring_service = 'red'):
     f.close()
 
     # call the sshfs command with the password from keyring if possible.
-    pw = None
     username = None
+    pw_keyring = None
+    username_keyring = None
     if sshfs_parameters[-2].find('@') > 0:
         username, server = sshfs_parameters[-2].split('@')
         server = server.split(':')[0]
         server = server.replace('.','_').replace('-','_')
 
-
         pw_keyring = server + '_password'
         username_keyring = server + '_username'
 
@@ -108,7 +108,8 @@ def new_sshfs_connection(sshfs_parameters, keyring_service = 'red'):
         bash.expect_exact(pexpect.EOF)
 
     else:
-        print(subprocess.call(['sshfs'] + sshfs_parameters[:-1] + [dest]))
+        subprocess.check_call(['sshfs'] + sshfs_parameters[:-1] + [dest])
+
     # Finden der wichtigen Parameter
     data_username, data_server, data_path = get_mount_values_for_a_direcotry(dest)
     if data_server is None or data_server == 'null':
